@@ -48,7 +48,7 @@ def doks(
         path to the Python file or module.
 
       target
-        path to the output file or ``None``, in which case
+        path to the output file or `None`, in which case
         output is printed to stdout
 
       auto
@@ -100,7 +100,7 @@ def doks(
     with safer.writer(target) as fp:
         fp.write(body)
 
-    print(f'{target} {written})', file=sys.stderr)
+    print(f'{target} {written}', file=sys.stderr)
     return True
 
 
